pub struct CallInput { /* private fields */ }Expand description
Mutable call input assembled by kernel and guest adapters.
Implementations
Sourceimpl CallInput
impl CallInput
Sourcepub fn push(&mut self, input: ArgumentInput, origin: ArgumentOrigin)
pub fn push(&mut self, input: ArgumentInput, origin: ArgumentOrigin)
Appends an input without interpreting any earlier occurrence.
Sourcepub fn with(self, input: ArgumentInput, origin: ArgumentOrigin) -> Self
pub fn with(self, input: ArgumentInput, origin: ArgumentOrigin) -> Self
Appends an input and returns the stream for fluent adapter construction.
Sourcepub fn arguments(&self) -> &[BoundArgument]
pub fn arguments(&self) -> &[BoundArgument]
Returns the complete input stream in arrival order.